#!/user/bin/env node

const koa = require('koa'),
    koaBody = require('koa-body'),
    compress = require('koa-compress'),
    koaSession = require('koa-session'),
    serve = require('koa-static'),
    errorhandler = require('koa-errorhandler');

const path = require('path');
const app = koa();

app.use(koaBody({formidable:{uploadDir: path.join(__dirname,'tmpUploader')}}));
app.keys = ['chaowei','luo'];
app.use(koaSession(app));

app.use(compress({
  filter: function (content_type) {
  	return /text/i.test(content_type)
  },
  threshold: 2048,
  flush: require('zlib').Z_SYNC_FLUSH
}));

let indexRouter = require('./router');
let userRouter = require('./router/user');

app.use(indexRouter.routes()).use(indexRouter.allowedMethods());
app.use(userRouter.routes()).use(userRouter.allowedMethods());


app.use(serve(path.join(__dirname,'public')));

app.use(errorhandler());

if(module.parent){
    module.exports = app;
}else{
    let port = process.env.NODE_PORT || 3000;
    app.listen(port,function(){
        console.log(`listen on port:${port}`);
        require('open')(`http://localhost:${port}`);
    })
}