const Koa = require('koa');

const fs = require('fs'),
    path = require('path');

const koaSession = require('koa-session'),
    compress = require('koa-compress'),
    bodyParse = require('koa-body'),
    serve = require('koa-static');

const sysConfig = require('./config/sys');

let app = new Koa();

// app.use(async(ctx, next) => {
//     ctx.onerror = function() {
//         console.error(arguments[0]);
//     };
//     await next();
// });

app.keys = sysConfig.keys;

//compress
let compressConfig = {
    filter: function(content_type) {
        return /text/i.test(content_type) || content_type == 'application/javascript';
    },
    threshold: 2048,
    flush: require('zlib').Z_SYNC_FLUSH
};
app.use(compress(compressConfig));
//session
let sessionConfig = {
    key: Math.random().toString(32).substring(2),
    maxAge: 86400000,
    overwrite: true,
    httpOnly: true,
    signed: true,
    rolling: false,
};

app.use(koaSession(sessionConfig, app));

//bodyParse
let bodyParseConfig = {
    formidable: {
        uploadDir: sysConfig.uploadRoot
    }
};
app.use(bodyParse(bodyParseConfig));

app.use(require('./mids/route.js')(path.join(__dirname, 'router')));

//static
app.use(serve(sysConfig.staticRoot));

if (process.env.NODE_ENV === 'development') {
    console.log('api ')
    app.use(serve(path.join(__dirname, 'api')));
}

let port = process.env.port || sysConfig.port || 3000;
app.listen(port, function() {
    console.log(`listen on port:${port}`);
    if (process.env.NODE_ENV === 'development') {
        require('open')('http://127.0.0.1:' + port);
    }
});